#!/usr/bin/env python2.5
import trackercfgmain
import gtk
prefs = trackercfgmain.TrackerPrefs()
gtk.main()

